package org.gcube.data.transfer.library.client;

import javax.ws.rs.client.ClientBuilder;
import javax.ws.rs.client.Entity;
import javax.ws.rs.client.WebTarget;
import javax.ws.rs.core.MediaType;
import javax.xml.bind.JAXBElement;

import lombok.extern.slf4j.Slf4j;

import org.gcube.data.transfer.model.ServiceConstants;
import org.gcube.data.transfer.model.TransferCapabilities;
import org.gcube.data.transfer.model.TransferRequest;
import org.gcube.data.transfer.model.TransferTicket;
import org.glassfish.jersey.client.ClientConfig;

@Slf4j
public class Client {

	private static ClientConfig config=null;
	
	static{
		log.debug("Creating configuration ..");
		config=new ClientConfig();
		config.register(AuthorizationFilter.class);
		config.register(JAXBElement.class);
	}
	
	private String hostname;

	private WebTarget rootTarget;
	
	public Client(String hostname){
		log.debug("Creating client for "+hostname);
		this.hostname=hostname;
		rootTarget= ClientBuilder.newClient(config).target(hostname).path("/data-transfer-service/").path(ServiceConstants.APPLICATION_PATH);		
	}
	
	public TransferCapabilities getCapabilties(){
		return rootTarget.path(ServiceConstants.CAPABILTIES_SERVLET_NAME).request(MediaType.APPLICATION_XML_TYPE).get(TransferCapabilities.class);
	}
	
	
	public TransferTicket submit(TransferRequest request){
		return rootTarget.path(ServiceConstants.REQUESTS_SERVLET_NAME).request(MediaType.APPLICATION_XML_TYPE).post(Entity.entity(request,MediaType.APPLICATION_XML),TransferTicket.class);
	}
	
	public TransferTicket getTransferStatus(String transferId){
		return rootTarget.path(ServiceConstants.STATUS_SERVLET_NAME).path(transferId).request(MediaType.APPLICATION_XML).get(TransferTicket.class);
	}
}
